@@ -3,15 +3,20 @@ python-introspect: Pure Python introspection toolkit
 
 This package provides utilities for introspecting Python functions, methods,
 dataclasses, and type hints.
+
+Extensibility:
+    Use register_namespace_provider() and register_type_resolver() to extend
+    type resolution for framework-specific types (lazy configs, proxies, etc.)
 """
 
-__version__ = "0.1.2"
+__version__ = "0.1.3"
 
 from .signature_analyzer import (
     SignatureAnalyzer,
     ParameterInfo,
     DocstringInfo,
     DocstringExtractor,
+    # Plugin registration
     register_namespace_provider,
     register_type_resolver,
 )
@@ -25,6 +30,12 @@ from .exceptions import (
     DocstringParsingError,
     TypeResolutionError,
 )
+from .enableable import (
+    Enableable,
+    is_enableable,
+    mark_enableable,
+    ENABLED_FIELD,
+)
 
 __all__ = [
     # Version
@@ -34,15 +45,20 @@ __all__ = [
     "ParameterInfo",
     "DocstringInfo",
     "DocstringExtractor",
+    # Plugin registration
+    "register_namespace_provider",
+    "register_type_resolver",
     # Unified analysis
     "UnifiedParameterAnalyzer",
     "UnifiedParameterInfo",
-    # Plugin system
-    "register_namespace_provider",
-    "register_type_resolver",
     # Exceptions
     "IntrospectionError",
     "SignatureAnalysisError",
     "DocstringParsingError",
     "TypeResolutionError",
+    # Enableable
+    "Enableable",
+    "is_enableable",
+    "mark_enableable",
+    "ENABLED_FIELD",
 ]
