@@ -1,86 +1,82 @@
 # File: python_introspect/signature_analyzer.py
+"""
+Signature analysis with extensible type resolution.
+
+This module provides pure Python introspection with a plugin architecture
+for framework-specific extensions. Register namespace providers and type
+resolvers to extend functionality without modifying this code.
+"""
 
 import ast
 import inspect
 import dataclasses
 import re
 from typing import Any, Dict, Callable, get_type_hints, NamedTuple, Union, Optional, Type, List
+
 from dataclasses import dataclass
 
-# Plugin system for namespace and type resolution
-# External packages can register their own providers/resolvers
+# =============================================================================
+# PLUGIN REGISTRY - Allows frameworks to extend type resolution
+# =============================================================================
+
+# Namespace providers: functions that return Dict[str, Any] for get_type_hints()
+# Used to resolve forward references like "GlobalPipelineConfig" -> actual class
 _namespace_providers: List[Callable[[], Dict[str, Any]]] = []
+
+# Type resolvers: functions that map types to their "real" types
+# e.g., LazyWellFilterConfig -> WellFilterConfig
 _type_resolvers: List[Callable[[type], Optional[type]]] = []
 
 
 def register_namespace_provider(provider: Callable[[], Dict[str, Any]]) -> None:
     """Register a namespace provider for forward reference resolution.
 
-    Args:
-        provider: A callable that returns a dict of names to types/values
-                 to be used when resolving forward references in type hints.
+    The provider function should return a dict of names to types/values
+    that will be available during get_type_hints() resolution.
 
     Example:
-        def my_namespace_provider():
-            import mypackage
-            return vars(mypackage)
-
-        register_namespace_provider(my_namespace_provider)
+        register_namespace_provider(lambda: {'MyClass': MyClass, 'MyEnum': MyEnum})
     """
     _namespace_providers.append(provider)
 
 
 def register_type_resolver(resolver: Callable[[type], Optional[type]]) -> None:
-    """Register a type resolver for custom type transformations.
+    """Register a type resolver for lazy/proxy type unwrapping.
 
-    Args:
-        resolver: A callable that takes a type and returns either:
-                 - A transformed type (e.g., LazyConfig -> Config)
-                 - None to defer to other resolvers
+    The resolver function should return the resolved type if it can handle
+    the input type, or None to defer to other resolvers.
 
     Example:
-        def my_type_resolver(t):
+        def resolve_lazy(t):
             if t.__name__.startswith('Lazy'):
                 return get_base_type(t)
             return None
-
-        register_type_resolver(my_type_resolver)
+        register_type_resolver(resolve_lazy)
     """
     _type_resolvers.append(resolver)
 
 
-def _get_registered_namespaces() -> Dict[str, Any]:
-    """Get all registered namespaces merged together."""
-    result = {}
+def _get_extended_namespace() -> Dict[str, Any]:
+    """Get combined namespace from all registered providers."""
+    result: Dict[str, Any] = {}
     for provider in _namespace_providers:
         try:
-            namespace = provider()
-            if namespace:
-                result.update(namespace)
+            result.update(provider())
         except Exception:
-            # Silently skip providers that fail
-            pass
+            pass  # Ignore providers that fail
     return result
 
 
 def _resolve_type(t: type) -> type:
-    """Resolve a type using registered type resolvers.
-
-    Args:
-        t: The type to resolve
-
-    Returns:
-        The resolved type, or the original type if no resolver handled it
-    """
+    """Resolve a type through registered resolvers, returning the unwrapped type."""
     for resolver in _type_resolvers:
         try:
             resolved = resolver(t)
             if resolved is not None:
                 return resolved
         except Exception:
-            # Silently skip resolvers that fail
-            pass
-    return t
+            pass  # Ignore resolvers that fail
+    return t  # No resolver handled it, return as-is
 
 
 @dataclass(frozen=True)
@@ -440,13 +436,14 @@ class SignatureAnalyzer:
         """
         sig = inspect.signature(callable_obj)
         # Build comprehensive namespace for forward reference resolution
-        # Start with registered namespaces, then add function's globals
+        # Start with registered namespace providers, then add function's globals
+        extended_ns = _get_extended_namespace()
         globalns = {
-            **_get_registered_namespaces(),
+            **extended_ns,
             **getattr(callable_obj, '__globals__', {})
         }
 
-        # For functions with a module, prioritize the function's actual module globals
+        # Prioritize the function's actual module globals for type resolution
         if hasattr(callable_obj, '__module__') and callable_obj.__module__:
             try:
                 import sys
@@ -454,7 +451,7 @@ class SignatureAnalyzer:
                 if actual_module:
                     # Function's module globals should take precedence for type resolution
                     globalns = {
-                        **_get_registered_namespaces(),
+                        **extended_ns,
                         **vars(actual_module)  # This overwrites with the actual module types
                     }
             except Exception:
@@ -640,10 +637,10 @@ class SignatureAnalyzer:
         # Use the class object itself as the key (classes are hashable and have stable identity)
         cache_key = dataclass_type
         if cache_key in SignatureAnalyzer._dataclass_analysis_cache:
-            logger.info(f"✅ CACHE HIT for {dataclass_type.__name__} (id={id(dataclass_type)})")
+            logger.debug(f"✅ CACHE HIT for {dataclass_type.__name__} (id={id(dataclass_type)})")
             return SignatureAnalyzer._dataclass_analysis_cache[cache_key]
 
-        logger.info(f"❌ CACHE MISS for {dataclass_type.__name__} (id={id(dataclass_type)}), cache has {len(SignatureAnalyzer._dataclass_analysis_cache)} entries")
+        logger.debug(f"❌ CACHE MISS for {dataclass_type.__name__} (id={id(dataclass_type)}), cache has {len(SignatureAnalyzer._dataclass_analysis_cache)} entries")
 
         try:
             # Try to get type hints, fall back to __annotations__ if resolution fails
@@ -1013,7 +1010,8 @@ class SignatureAnalyzer:
     def _resolve_lazy_dataclass_for_docs(dataclass_type: type) -> type:
         """Resolve lazy dataclasses to their base classes for documentation extraction.
 
-        Uses registered type resolvers to handle custom type transformations.
+        Uses registered type resolvers to unwrap lazy/proxy types.
+        Falls back to heuristics if no resolver handles the type.
 
         Args:
             dataclass_type: The dataclass type (potentially lazy)
@@ -1021,7 +1019,40 @@ class SignatureAnalyzer:
         Returns:
             The resolved dataclass type for documentation extraction
         """
-        return _resolve_type(dataclass_type)
+        try:
+            # First, try registered type resolvers (framework-specific)
+            resolved = _resolve_type(dataclass_type)
+            if resolved is not dataclass_type:
+                return resolved
+
+            # Fallback heuristics for common patterns (framework-agnostic)
+            class_name = dataclass_type.__name__
+
+            # Handle LazyXxxConfig -> XxxConfig by looking in same module
+            if class_name.startswith('Lazy') and class_name.endswith('Config'):
+                try:
+                    base_class_name = class_name[4:]  # Remove 'Lazy' prefix
+                    module = __import__(dataclass_type.__module__, fromlist=[base_class_name])
+                    if hasattr(module, base_class_name):
+                        return getattr(module, base_class_name)
+                except (ImportError, AttributeError):
+                    pass
+
+            # Try to find GlobalXxxConfig version in same module
+            if not class_name.startswith('Global') and class_name.endswith('Config'):
+                try:
+                    global_class_name = f'Global{class_name}'
+                    module = __import__(dataclass_type.__module__, fromlist=[global_class_name])
+                    if hasattr(module, global_class_name):
+                        return getattr(module, global_class_name)
+                except (ImportError, AttributeError):
+                    pass
+
+            # If no resolution found, return the original type
+            return dataclass_type
+
+        except Exception:
+            return dataclass_type
 
     @staticmethod
     def _extract_all_field_docs(dataclass_type: type) -> Dict[str, str]:
@@ -1120,16 +1151,12 @@ class SignatureAnalyzer:
             parameters = SignatureAnalyzer._analyze_dataclass(dataclass_type)
 
             # Update default values with current instance values
-            # For lazy dataclasses, use object.__getattribute__ to preserve None values for placeholders
+            # CRITICAL: Always use object.__getattribute__ to bypass __getattribute__ overrides
+            # This ensures we get the raw stored value, not a resolved/computed value
             for name, param_info in parameters.items():
-                if hasattr(instance, name):
-                    # Check if this is a lazy dataclass that should preserve None values
-                    if hasattr(instance, '_resolve_field_value'):
-                        # This is a lazy dataclass - use object.__getattribute__ to get stored value
-                        current_value = object.__getattribute__(instance, name)
-                    else:
-                        # Regular dataclass - use normal getattr
-                        current_value = getattr(instance, name)
+                try:
+                    # Bypass __getattribute__ to get raw stored value (not resolved)
+                    current_value = object.__getattribute__(instance, name)
 
                     # Create new ParameterInfo with current value as default
                     parameters[name] = ParameterInfo(
@@ -1139,6 +1166,9 @@ class SignatureAnalyzer:
                         is_required=param_info.is_required,
                         description=param_info.description
                     )
+                except AttributeError:
+                    # Field doesn't exist on instance, keep signature default
+                    pass
 
             return parameters
 
